==> libreoffice_4.3.2.orig.tar.xz: libreoffice-4.3.2.2/forms/qa/integration/forms/ListSelectionValidator.java <==
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

package integration.forms;

public class ListSelectionValidator extends integration.forms.ControlValidator
{
    /** Creates a new instance of ListSelectionValidator */
    public ListSelectionValidator()
    {
    }

    public String explainInvalid( Object Value )
    {
        try
        {
            short[] selectionIndexes = (short[])Value;
            if ( selectionIndexes.length > 2 )
                return "please 2 entries, at most";
        }
        catch( java.lang.Exception e )
        {
            return "oops. What's this?";
        }
        return "";
    }

    public boolean isValid( Object Value )
    {
        try
        {
            short[] selectionIndexes = (short[])Value;
            if ( selectionIndexes.length > 2 )
                return false;
            return true;
        }
        catch( java.lang.Exception e )
        {
        }
        return false;
    }

}

==> libreoffice-26.2.0.3.tar.xz: libreoffice-26.2.0.3/forms/qa/integration/forms/ListSelectionValidator.java <==
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

package integration.forms;

public class ListSelectionValidator extends integration.forms.ControlValidator
{
    public String explainInvalid( Object Value )
    {
        try
        {
            short[] selectionIndexes = (short[])Value;
            if ( selectionIndexes.length > 2 )
                return "please 2 entries, at most";
        }
        catch( java.lang.Exception e )
        {
            return "oops. What's this?";
        }
        return "";
    }

    public boolean isValid( Object Value )
    {
        try
        {
            short[] selectionIndexes = (short[])Value;
            return selectionIndexes.length <= 2;
        }
        catch( java.lang.Exception e )
        {
        }
        return false;
    }

}
